@@ -15,20 +15,18 @@
 #
 import abc
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
-import pkg_resources
 
-import google.auth  # type: ignore
 import google.api_core
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, operations_v1
 from google.api_core import retry as retries
-from google.api_core import operations_v1
+import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
-from google.oauth2 import service_account  # type: ignore
-
-from google.cloud.security.privateca_v1.types import resources
-from google.cloud.security.privateca_v1.types import service
 from google.longrunning import operations_pb2  # type: ignore
+from google.oauth2 import service_account  # type: ignore
+import pkg_resources
+
+from google.cloud.security.privateca_v1.types import resources, service
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
@@ -57,6 +55,7 @@ class CertificateAuthorityServiceTransport(abc.ABC):
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
         **kwargs,
     ) -> None:
         """Instantiate the transport.
@@ -83,10 +82,6 @@ class CertificateAuthorityServiceTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
-        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
-        if ":" not in host:
-            host += ":443"
-        self._host = host
 
         scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}
 
@@ -108,6 +103,11 @@ class CertificateAuthorityServiceTransport(abc.ABC):
             credentials, _ = google.auth.default(
                 **scopes_kwargs, quota_project_id=quota_project_id
             )
+            # Don't apply audience if the credentials file passed from user.
+            if hasattr(credentials, "with_gdch_audience"):
+                credentials = credentials.with_gdch_audience(
+                    api_audience if api_audience else host
+                )
 
         # If the credentials are service account credentials, then always try to use self signed JWT.
         if (
@@ -120,23 +120,38 @@ class CertificateAuthorityServiceTransport(abc.ABC):
         # Save the credentials.
         self._credentials = credentials
 
+        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
+        if ":" not in host:
+            host += ":443"
+        self._host = host
+
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
             self.create_certificate: gapic_v1.method.wrap_method(
-                self.create_certificate, default_timeout=None, client_info=client_info,
+                self.create_certificate,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_certificate: gapic_v1.method.wrap_method(
-                self.get_certificate, default_timeout=None, client_info=client_info,
+                self.get_certificate,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.list_certificates: gapic_v1.method.wrap_method(
-                self.list_certificates, default_timeout=None, client_info=client_info,
+                self.list_certificates,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.revoke_certificate: gapic_v1.method.wrap_method(
-                self.revoke_certificate, default_timeout=None, client_info=client_info,
+                self.revoke_certificate,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.update_certificate: gapic_v1.method.wrap_method(
-                self.update_certificate, default_timeout=None, client_info=client_info,
+                self.update_certificate,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.activate_certificate_authority: gapic_v1.method.wrap_method(
                 self.activate_certificate_authority,
@@ -189,22 +204,34 @@ class CertificateAuthorityServiceTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.create_ca_pool: gapic_v1.method.wrap_method(
-                self.create_ca_pool, default_timeout=None, client_info=client_info,
+                self.create_ca_pool,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.update_ca_pool: gapic_v1.method.wrap_method(
-                self.update_ca_pool, default_timeout=None, client_info=client_info,
+                self.update_ca_pool,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_ca_pool: gapic_v1.method.wrap_method(
-                self.get_ca_pool, default_timeout=None, client_info=client_info,
+                self.get_ca_pool,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.list_ca_pools: gapic_v1.method.wrap_method(
-                self.list_ca_pools, default_timeout=None, client_info=client_info,
+                self.list_ca_pools,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.delete_ca_pool: gapic_v1.method.wrap_method(
-                self.delete_ca_pool, default_timeout=None, client_info=client_info,
+                self.delete_ca_pool,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.fetch_ca_certs: gapic_v1.method.wrap_method(
-                self.fetch_ca_certs, default_timeout=None, client_info=client_info,
+                self.fetch_ca_certs,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_certificate_revocation_list: gapic_v1.method.wrap_method(
                 self.get_certificate_revocation_list,
@@ -251,9 +278,9 @@ class CertificateAuthorityServiceTransport(abc.ABC):
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -542,5 +569,9 @@ class CertificateAuthorityServiceTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("CertificateAuthorityServiceTransport",)
