@@ -13,22 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import grpc_helpers
-from google.api_core import operations_v1
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, grpc_helpers, operations_v1
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 import grpc  # type: ignore
 
-from google.cloud.security.privateca_v1.types import resources
-from google.cloud.security.privateca_v1.types import service
-from google.longrunning import operations_pb2  # type: ignore
-from .base import CertificateAuthorityServiceTransport, DEFAULT_CLIENT_INFO
+from google.cloud.security.privateca_v1.types import resources, service
+
+from .base import DEFAULT_CLIENT_INFO, CertificateAuthorityServiceTransport
 
 
 class CertificateAuthorityServiceGrpcTransport(CertificateAuthorityServiceTransport):
@@ -63,6 +60,7 @@ class CertificateAuthorityServiceGrpcTransport(CertificateAuthorityServiceTransp
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
     ) -> None:
         """Instantiate the transport.
 
@@ -159,6 +157,7 @@ class CertificateAuthorityServiceGrpcTransport(CertificateAuthorityServiceTransp
             quota_project_id=quota_project_id,
             client_info=client_info,
             always_use_jwt_access=always_use_jwt_access,
+            api_audience=api_audience,
         )
 
         if not self._grpc_channel:
@@ -230,8 +229,7 @@ class CertificateAuthorityServiceGrpcTransport(CertificateAuthorityServiceTransp
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -1109,5 +1107,9 @@ class CertificateAuthorityServiceGrpcTransport(CertificateAuthorityServiceTransp
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("CertificateAuthorityServiceGrpcTransport",)
