@@ -13,12 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
-
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.type import expr_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.security.privateca.v1",
@@ -179,7 +177,7 @@ class CertificateAuthority(proto.Message):
             will be permanently purged, if it is in the
             [DELETED][google.cloud.security.privateca.v1.CertificateAuthority.State.DELETED]
             state.
-        labels (Sequence[google.cloud.security.privateca_v1.types.CertificateAuthority.LabelsEntry]):
+        labels (Mapping[str, str]):
             Optional. Labels with user-defined metadata.
     """
 
@@ -243,8 +241,14 @@ class CertificateAuthority(proto.Message):
                 been activated.
         """
 
-        ca_certificate_access_url = proto.Field(proto.STRING, number=1,)
-        crl_access_urls = proto.RepeatedField(proto.STRING, number=2,)
+        ca_certificate_access_url = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        crl_access_urls = proto.RepeatedField(
+            proto.STRING,
+            number=2,
+        )
 
     class KeyVersionSpec(proto.Message):
         r"""A Cloud KMS key configuration that a
@@ -277,7 +281,11 @@ class CertificateAuthority(proto.Message):
                 This field is a member of `oneof`_ ``KeyVersion``.
         """
 
-        cloud_kms_key_version = proto.Field(proto.STRING, number=1, oneof="KeyVersion",)
+        cloud_kms_key_version = proto.Field(
+            proto.STRING,
+            number=1,
+            oneof="KeyVersion",
+        )
         algorithm = proto.Field(
             proto.ENUM,
             number=2,
@@ -285,35 +293,88 @@ class CertificateAuthority(proto.Message):
             enum="CertificateAuthority.SignHashAlgorithm",
         )
 
-    name = proto.Field(proto.STRING, number=1,)
-    type_ = proto.Field(proto.ENUM, number=2, enum=Type,)
-    config = proto.Field(proto.MESSAGE, number=3, message="CertificateConfig",)
-    lifetime = proto.Field(proto.MESSAGE, number=4, message=duration_pb2.Duration,)
-    key_spec = proto.Field(proto.MESSAGE, number=5, message=KeyVersionSpec,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    type_ = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=Type,
+    )
+    config = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="CertificateConfig",
+    )
+    lifetime = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=duration_pb2.Duration,
+    )
+    key_spec = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=KeyVersionSpec,
+    )
     subordinate_config = proto.Field(
-        proto.MESSAGE, number=6, message="SubordinateConfig",
+        proto.MESSAGE,
+        number=6,
+        message="SubordinateConfig",
+    )
+    tier = proto.Field(
+        proto.ENUM,
+        number=7,
+        enum="CaPool.Tier",
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=8,
+        enum=State,
+    )
+    pem_ca_certificates = proto.RepeatedField(
+        proto.STRING,
+        number=9,
     )
-    tier = proto.Field(proto.ENUM, number=7, enum="CaPool.Tier",)
-    state = proto.Field(proto.ENUM, number=8, enum=State,)
-    pem_ca_certificates = proto.RepeatedField(proto.STRING, number=9,)
     ca_certificate_descriptions = proto.RepeatedField(
-        proto.MESSAGE, number=10, message="CertificateDescription",
+        proto.MESSAGE,
+        number=10,
+        message="CertificateDescription",
+    )
+    gcs_bucket = proto.Field(
+        proto.STRING,
+        number=11,
+    )
+    access_urls = proto.Field(
+        proto.MESSAGE,
+        number=12,
+        message=AccessUrls,
     )
-    gcs_bucket = proto.Field(proto.STRING, number=11,)
-    access_urls = proto.Field(proto.MESSAGE, number=12, message=AccessUrls,)
     create_time = proto.Field(
-        proto.MESSAGE, number=13, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=13,
+        message=timestamp_pb2.Timestamp,
     )
     update_time = proto.Field(
-        proto.MESSAGE, number=14, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=14,
+        message=timestamp_pb2.Timestamp,
     )
     delete_time = proto.Field(
-        proto.MESSAGE, number=15, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=15,
+        message=timestamp_pb2.Timestamp,
     )
     expire_time = proto.Field(
-        proto.MESSAGE, number=16, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=16,
+        message=timestamp_pb2.Timestamp,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=17,
     )
-    labels = proto.MapField(proto.STRING, proto.STRING, number=17,)
 
 
 class CaPool(proto.Message):
@@ -351,7 +412,7 @@ class CaPool(proto.Message):
             from any
             [CertificateAuthority][google.cloud.security.privateca.v1.CertificateAuthority]
             in this [CaPool][google.cloud.security.privateca.v1.CaPool].
-        labels (Sequence[google.cloud.security.privateca_v1.types.CaPool.LabelsEntry]):
+        labels (Mapping[str, str]):
             Optional. Labels with user-defined metadata.
     """
 
@@ -395,8 +456,14 @@ class CaPool(proto.Message):
                 shortly after a certificate is revoked.
         """
 
-        publish_ca_cert = proto.Field(proto.BOOL, number=1,)
-        publish_crl = proto.Field(proto.BOOL, number=2,)
+        publish_ca_cert = proto.Field(
+            proto.BOOL,
+            number=1,
+        )
+        publish_crl = proto.Field(
+            proto.BOOL,
+            number=2,
+        )
 
     class IssuancePolicy(proto.Message):
         r"""Defines controls over all certificate issuance within a
@@ -512,8 +579,14 @@ class CaPool(proto.Message):
                         an explicit upper bound on RSA modulus sizes.
                 """
 
-                min_modulus_size = proto.Field(proto.INT64, number=1,)
-                max_modulus_size = proto.Field(proto.INT64, number=2,)
+                min_modulus_size = proto.Field(
+                    proto.INT64,
+                    number=1,
+                )
+                max_modulus_size = proto.Field(
+                    proto.INT64,
+                    number=2,
+                )
 
             class EcKeyType(proto.Message):
                 r"""Describes an Elliptic Curve key that may be used in a
@@ -576,35 +649,70 @@ class CaPool(proto.Message):
                     [CertificateConfig][google.cloud.security.privateca.v1.CertificateConfig].
             """
 
-            allow_csr_based_issuance = proto.Field(proto.BOOL, number=1,)
-            allow_config_based_issuance = proto.Field(proto.BOOL, number=2,)
+            allow_csr_based_issuance = proto.Field(
+                proto.BOOL,
+                number=1,
+            )
+            allow_config_based_issuance = proto.Field(
+                proto.BOOL,
+                number=2,
+            )
 
         allowed_key_types = proto.RepeatedField(
-            proto.MESSAGE, number=1, message="CaPool.IssuancePolicy.AllowedKeyType",
+            proto.MESSAGE,
+            number=1,
+            message="CaPool.IssuancePolicy.AllowedKeyType",
         )
         maximum_lifetime = proto.Field(
-            proto.MESSAGE, number=2, message=duration_pb2.Duration,
+            proto.MESSAGE,
+            number=2,
+            message=duration_pb2.Duration,
         )
         allowed_issuance_modes = proto.Field(
-            proto.MESSAGE, number=3, message="CaPool.IssuancePolicy.IssuanceModes",
+            proto.MESSAGE,
+            number=3,
+            message="CaPool.IssuancePolicy.IssuanceModes",
         )
         baseline_values = proto.Field(
-            proto.MESSAGE, number=4, message="X509Parameters",
+            proto.MESSAGE,
+            number=4,
+            message="X509Parameters",
         )
         identity_constraints = proto.Field(
-            proto.MESSAGE, number=5, message="CertificateIdentityConstraints",
+            proto.MESSAGE,
+            number=5,
+            message="CertificateIdentityConstraints",
         )
         passthrough_extensions = proto.Field(
-            proto.MESSAGE, number=6, message="CertificateExtensionConstraints",
+            proto.MESSAGE,
+            number=6,
+            message="CertificateExtensionConstraints",
         )
 
-    name = proto.Field(proto.STRING, number=1,)
-    tier = proto.Field(proto.ENUM, number=2, enum=Tier,)
-    issuance_policy = proto.Field(proto.MESSAGE, number=3, message=IssuancePolicy,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    tier = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=Tier,
+    )
+    issuance_policy = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=IssuancePolicy,
+    )
     publishing_options = proto.Field(
-        proto.MESSAGE, number=4, message=PublishingOptions,
+        proto.MESSAGE,
+        number=4,
+        message=PublishingOptions,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=5,
     )
-    labels = proto.MapField(proto.STRING, proto.STRING, number=5,)
 
 
 class CertificateRevocationList(proto.Message):
@@ -648,7 +756,7 @@ class CertificateRevocationList(proto.Message):
             [CertificateRevocationList][google.cloud.security.privateca.v1.CertificateRevocationList].
             A new revision is committed whenever a new CRL is published.
             The format is an 8-character hexadecimal string.
-        labels (Sequence[google.cloud.security.privateca_v1.types.CertificateRevocationList.LabelsEntry]):
+        labels (Mapping[str, str]):
             Optional. Labels with user-defined metadata.
     """
 
@@ -680,22 +788,65 @@ class CertificateRevocationList(proto.Message):
                 was revoked.
         """
 
-        certificate = proto.Field(proto.STRING, number=1,)
-        hex_serial_number = proto.Field(proto.STRING, number=2,)
-        revocation_reason = proto.Field(proto.ENUM, number=3, enum="RevocationReason",)
+        certificate = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        hex_serial_number = proto.Field(
+            proto.STRING,
+            number=2,
+        )
+        revocation_reason = proto.Field(
+            proto.ENUM,
+            number=3,
+            enum="RevocationReason",
+        )
 
-    name = proto.Field(proto.STRING, number=1,)
-    sequence_number = proto.Field(proto.INT64, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    sequence_number = proto.Field(
+        proto.INT64,
+        number=2,
+    )
     revoked_certificates = proto.RepeatedField(
-        proto.MESSAGE, number=3, message=RevokedCertificate,
+        proto.MESSAGE,
+        number=3,
+        message=RevokedCertificate,
+    )
+    pem_crl = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    access_url = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=6,
+        enum=State,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=8,
+        message=timestamp_pb2.Timestamp,
+    )
+    revision_id = proto.Field(
+        proto.STRING,
+        number=9,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=10,
     )
-    pem_crl = proto.Field(proto.STRING, number=4,)
-    access_url = proto.Field(proto.STRING, number=5,)
-    state = proto.Field(proto.ENUM, number=6, enum=State,)
-    create_time = proto.Field(proto.MESSAGE, number=7, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=8, message=timestamp_pb2.Timestamp,)
-    revision_id = proto.Field(proto.STRING, number=9,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=10,)
 
 
 class Certificate(proto.Message):
@@ -775,7 +926,7 @@ class Certificate(proto.Message):
             Output only. The time at which this
             [Certificate][google.cloud.security.privateca.v1.Certificate]
             was updated.
-        labels (Sequence[google.cloud.security.privateca_v1.types.Certificate.LabelsEntry]):
+        labels (Mapping[str, str]):
             Optional. Labels with user-defined metadata.
     """
 
@@ -794,38 +945,83 @@ class Certificate(proto.Message):
                 was revoked.
         """
 
-        revocation_state = proto.Field(proto.ENUM, number=1, enum="RevocationReason",)
+        revocation_state = proto.Field(
+            proto.ENUM,
+            number=1,
+            enum="RevocationReason",
+        )
         revocation_time = proto.Field(
-            proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,
+            proto.MESSAGE,
+            number=2,
+            message=timestamp_pb2.Timestamp,
         )
 
-    name = proto.Field(proto.STRING, number=1,)
-    pem_csr = proto.Field(proto.STRING, number=2, oneof="certificate_config",)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    pem_csr = proto.Field(
+        proto.STRING,
+        number=2,
+        oneof="certificate_config",
+    )
     config = proto.Field(
         proto.MESSAGE,
         number=3,
         oneof="certificate_config",
         message="CertificateConfig",
     )
-    issuer_certificate_authority = proto.Field(proto.STRING, number=4,)
-    lifetime = proto.Field(proto.MESSAGE, number=5, message=duration_pb2.Duration,)
-    certificate_template = proto.Field(proto.STRING, number=6,)
-    subject_mode = proto.Field(proto.ENUM, number=7, enum="SubjectRequestMode",)
+    issuer_certificate_authority = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    lifetime = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=duration_pb2.Duration,
+    )
+    certificate_template = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    subject_mode = proto.Field(
+        proto.ENUM,
+        number=7,
+        enum="SubjectRequestMode",
+    )
     revocation_details = proto.Field(
-        proto.MESSAGE, number=8, message=RevocationDetails,
+        proto.MESSAGE,
+        number=8,
+        message=RevocationDetails,
+    )
+    pem_certificate = proto.Field(
+        proto.STRING,
+        number=9,
     )
-    pem_certificate = proto.Field(proto.STRING, number=9,)
     certificate_description = proto.Field(
-        proto.MESSAGE, number=10, message="CertificateDescription",
+        proto.MESSAGE,
+        number=10,
+        message="CertificateDescription",
+    )
+    pem_certificate_chain = proto.RepeatedField(
+        proto.STRING,
+        number=11,
     )
-    pem_certificate_chain = proto.RepeatedField(proto.STRING, number=11,)
     create_time = proto.Field(
-        proto.MESSAGE, number=12, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=12,
+        message=timestamp_pb2.Timestamp,
     )
     update_time = proto.Field(
-        proto.MESSAGE, number=13, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=13,
+        message=timestamp_pb2.Timestamp,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=14,
     )
-    labels = proto.MapField(proto.STRING, proto.STRING, number=14,)
 
 
 class CertificateTemplate(proto.Message):
@@ -889,22 +1085,48 @@ class CertificateTemplate(proto.Message):
             Output only. The time at which this
             [CertificateTemplate][google.cloud.security.privateca.v1.CertificateTemplate]
             was updated.
-        labels (Sequence[google.cloud.security.privateca_v1.types.CertificateTemplate.LabelsEntry]):
+        labels (Mapping[str, str]):
             Optional. Labels with user-defined metadata.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    predefined_values = proto.Field(proto.MESSAGE, number=2, message="X509Parameters",)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    predefined_values = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="X509Parameters",
+    )
     identity_constraints = proto.Field(
-        proto.MESSAGE, number=3, message="CertificateIdentityConstraints",
+        proto.MESSAGE,
+        number=3,
+        message="CertificateIdentityConstraints",
     )
     passthrough_extensions = proto.Field(
-        proto.MESSAGE, number=4, message="CertificateExtensionConstraints",
+        proto.MESSAGE,
+        number=4,
+        message="CertificateExtensionConstraints",
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message=timestamp_pb2.Timestamp,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=8,
     )
-    description = proto.Field(proto.STRING, number=5,)
-    create_time = proto.Field(proto.MESSAGE, number=6, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=7, message=timestamp_pb2.Timestamp,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=8,)
 
 
 class X509Parameters(proto.Message):
@@ -958,15 +1180,40 @@ class X509Parameters(proto.Message):
                 This field is a member of `oneof`_ ``_max_issuer_path_length``.
         """
 
-        is_ca = proto.Field(proto.BOOL, number=1, optional=True,)
-        max_issuer_path_length = proto.Field(proto.INT32, number=2, optional=True,)
+        is_ca = proto.Field(
+            proto.BOOL,
+            number=1,
+            optional=True,
+        )
+        max_issuer_path_length = proto.Field(
+            proto.INT32,
+            number=2,
+            optional=True,
+        )
 
-    key_usage = proto.Field(proto.MESSAGE, number=1, message="KeyUsage",)
-    ca_options = proto.Field(proto.MESSAGE, number=2, message=CaOptions,)
-    policy_ids = proto.RepeatedField(proto.MESSAGE, number=3, message="ObjectId",)
-    aia_ocsp_servers = proto.RepeatedField(proto.STRING, number=4,)
+    key_usage = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="KeyUsage",
+    )
+    ca_options = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=CaOptions,
+    )
+    policy_ids = proto.RepeatedField(
+        proto.MESSAGE,
+        number=3,
+        message="ObjectId",
+    )
+    aia_ocsp_servers = proto.RepeatedField(
+        proto.STRING,
+        number=4,
+    )
     additional_extensions = proto.RepeatedField(
-        proto.MESSAGE, number=5, message="X509Extension",
+        proto.MESSAGE,
+        number=5,
+        message="X509Extension",
     )
 
 
@@ -1013,10 +1260,15 @@ class SubordinateConfig(proto.Message):
                 order according to RFC 5246.
         """
 
-        pem_certificates = proto.RepeatedField(proto.STRING, number=1,)
+        pem_certificates = proto.RepeatedField(
+            proto.STRING,
+            number=1,
+        )
 
     certificate_authority = proto.Field(
-        proto.STRING, number=1, oneof="subordinate_config",
+        proto.STRING,
+        number=1,
+        oneof="subordinate_config",
     )
     pem_issuer_chain = proto.Field(
         proto.MESSAGE,
@@ -1046,8 +1298,15 @@ class PublicKey(proto.Message):
         KEY_FORMAT_UNSPECIFIED = 0
         PEM = 1
 
-    key = proto.Field(proto.BYTES, number=1,)
-    format_ = proto.Field(proto.ENUM, number=2, enum=KeyFormat,)
+    key = proto.Field(
+        proto.BYTES,
+        number=1,
+    )
+    format_ = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=KeyFormat,
+    )
 
 
 class CertificateConfig(proto.Message):
@@ -1089,14 +1348,32 @@ class CertificateConfig(proto.Message):
                 fields.
         """
 
-        subject = proto.Field(proto.MESSAGE, number=1, message="Subject",)
+        subject = proto.Field(
+            proto.MESSAGE,
+            number=1,
+            message="Subject",
+        )
         subject_alt_name = proto.Field(
-            proto.MESSAGE, number=2, message="SubjectAltNames",
+            proto.MESSAGE,
+            number=2,
+            message="SubjectAltNames",
         )
 
-    subject_config = proto.Field(proto.MESSAGE, number=1, message=SubjectConfig,)
-    x509_config = proto.Field(proto.MESSAGE, number=2, message="X509Parameters",)
-    public_key = proto.Field(proto.MESSAGE, number=3, message="PublicKey",)
+    subject_config = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=SubjectConfig,
+    )
+    x509_config = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="X509Parameters",
+    )
+    public_key = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="PublicKey",
+    )
 
 
 class CertificateDescription(proto.Message):
@@ -1162,17 +1439,34 @@ class CertificateDescription(proto.Message):
                 Corresponds to 'not_before_time' + 'lifetime' - 1 second.
         """
 
-        subject = proto.Field(proto.MESSAGE, number=1, message="Subject",)
+        subject = proto.Field(
+            proto.MESSAGE,
+            number=1,
+            message="Subject",
+        )
         subject_alt_name = proto.Field(
-            proto.MESSAGE, number=2, message="SubjectAltNames",
+            proto.MESSAGE,
+            number=2,
+            message="SubjectAltNames",
+        )
+        hex_serial_number = proto.Field(
+            proto.STRING,
+            number=3,
+        )
+        lifetime = proto.Field(
+            proto.MESSAGE,
+            number=4,
+            message=duration_pb2.Duration,
         )
-        hex_serial_number = proto.Field(proto.STRING, number=3,)
-        lifetime = proto.Field(proto.MESSAGE, number=4, message=duration_pb2.Duration,)
         not_before_time = proto.Field(
-            proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,
+            proto.MESSAGE,
+            number=5,
+            message=timestamp_pb2.Timestamp,
         )
         not_after_time = proto.Field(
-            proto.MESSAGE, number=6, message=timestamp_pb2.Timestamp,
+            proto.MESSAGE,
+            number=6,
+            message=timestamp_pb2.Timestamp,
         )
 
     class KeyId(proto.Message):
@@ -1186,7 +1480,10 @@ class CertificateDescription(proto.Message):
                 160 bit SHA-1 hash of the public key.
         """
 
-        key_id = proto.Field(proto.STRING, number=1,)
+        key_id = proto.Field(
+            proto.STRING,
+            number=1,
+        )
 
     class CertificateFingerprint(proto.Message):
         r"""A group of fingerprints for the x509 certificate.
@@ -1197,19 +1494,48 @@ class CertificateDescription(proto.Message):
                 the DER x509 certificate.
         """
 
-        sha256_hash = proto.Field(proto.STRING, number=1,)
+        sha256_hash = proto.Field(
+            proto.STRING,
+            number=1,
+        )
 
     subject_description = proto.Field(
-        proto.MESSAGE, number=1, message=SubjectDescription,
+        proto.MESSAGE,
+        number=1,
+        message=SubjectDescription,
+    )
+    x509_description = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="X509Parameters",
+    )
+    public_key = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="PublicKey",
+    )
+    subject_key_id = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=KeyId,
+    )
+    authority_key_id = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=KeyId,
+    )
+    crl_distribution_points = proto.RepeatedField(
+        proto.STRING,
+        number=6,
+    )
+    aia_issuing_certificate_urls = proto.RepeatedField(
+        proto.STRING,
+        number=7,
     )
-    x509_description = proto.Field(proto.MESSAGE, number=2, message="X509Parameters",)
-    public_key = proto.Field(proto.MESSAGE, number=3, message="PublicKey",)
-    subject_key_id = proto.Field(proto.MESSAGE, number=4, message=KeyId,)
-    authority_key_id = proto.Field(proto.MESSAGE, number=5, message=KeyId,)
-    crl_distribution_points = proto.RepeatedField(proto.STRING, number=6,)
-    aia_issuing_certificate_urls = proto.RepeatedField(proto.STRING, number=7,)
     cert_fingerprint = proto.Field(
-        proto.MESSAGE, number=8, message=CertificateFingerprint,
+        proto.MESSAGE,
+        number=8,
+        message=CertificateFingerprint,
     )
 
 
@@ -1224,7 +1550,10 @@ class ObjectId(proto.Message):
             significant parts of the path come first.
     """
 
-    object_id_path = proto.RepeatedField(proto.INT32, number=1,)
+    object_id_path = proto.RepeatedField(
+        proto.INT32,
+        number=1,
+    )
 
 
 class X509Extension(proto.Message):
@@ -1244,9 +1573,19 @@ class X509Extension(proto.Message):
             Required. The value of this X.509 extension.
     """
 
-    object_id = proto.Field(proto.MESSAGE, number=1, message="ObjectId",)
-    critical = proto.Field(proto.BOOL, number=2,)
-    value = proto.Field(proto.BYTES, number=3,)
+    object_id = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="ObjectId",
+    )
+    critical = proto.Field(
+        proto.BOOL,
+        number=2,
+    )
+    value = proto.Field(
+        proto.BYTES,
+        number=3,
+    )
 
 
 class KeyUsage(proto.Message):
@@ -1297,15 +1636,42 @@ class KeyUsage(proto.Message):
                 The key may be used to decipher only.
         """
 
-        digital_signature = proto.Field(proto.BOOL, number=1,)
-        content_commitment = proto.Field(proto.BOOL, number=2,)
-        key_encipherment = proto.Field(proto.BOOL, number=3,)
-        data_encipherment = proto.Field(proto.BOOL, number=4,)
-        key_agreement = proto.Field(proto.BOOL, number=5,)
-        cert_sign = proto.Field(proto.BOOL, number=6,)
-        crl_sign = proto.Field(proto.BOOL, number=7,)
-        encipher_only = proto.Field(proto.BOOL, number=8,)
-        decipher_only = proto.Field(proto.BOOL, number=9,)
+        digital_signature = proto.Field(
+            proto.BOOL,
+            number=1,
+        )
+        content_commitment = proto.Field(
+            proto.BOOL,
+            number=2,
+        )
+        key_encipherment = proto.Field(
+            proto.BOOL,
+            number=3,
+        )
+        data_encipherment = proto.Field(
+            proto.BOOL,
+            number=4,
+        )
+        key_agreement = proto.Field(
+            proto.BOOL,
+            number=5,
+        )
+        cert_sign = proto.Field(
+            proto.BOOL,
+            number=6,
+        )
+        crl_sign = proto.Field(
+            proto.BOOL,
+            number=7,
+        )
+        encipher_only = proto.Field(
+            proto.BOOL,
+            number=8,
+        )
+        decipher_only = proto.Field(
+            proto.BOOL,
+            number=9,
+        )
 
     class ExtendedKeyUsageOptions(proto.Message):
         r"""[KeyUsage.ExtendedKeyUsageOptions][google.cloud.security.privateca.v1.KeyUsage.ExtendedKeyUsageOptions]
@@ -1340,19 +1706,45 @@ class KeyUsage(proto.Message):
                 responses".
         """
 
-        server_auth = proto.Field(proto.BOOL, number=1,)
-        client_auth = proto.Field(proto.BOOL, number=2,)
-        code_signing = proto.Field(proto.BOOL, number=3,)
-        email_protection = proto.Field(proto.BOOL, number=4,)
-        time_stamping = proto.Field(proto.BOOL, number=5,)
-        ocsp_signing = proto.Field(proto.BOOL, number=6,)
+        server_auth = proto.Field(
+            proto.BOOL,
+            number=1,
+        )
+        client_auth = proto.Field(
+            proto.BOOL,
+            number=2,
+        )
+        code_signing = proto.Field(
+            proto.BOOL,
+            number=3,
+        )
+        email_protection = proto.Field(
+            proto.BOOL,
+            number=4,
+        )
+        time_stamping = proto.Field(
+            proto.BOOL,
+            number=5,
+        )
+        ocsp_signing = proto.Field(
+            proto.BOOL,
+            number=6,
+        )
 
-    base_key_usage = proto.Field(proto.MESSAGE, number=1, message=KeyUsageOptions,)
+    base_key_usage = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=KeyUsageOptions,
+    )
     extended_key_usage = proto.Field(
-        proto.MESSAGE, number=2, message=ExtendedKeyUsageOptions,
+        proto.MESSAGE,
+        number=2,
+        message=ExtendedKeyUsageOptions,
     )
     unknown_extended_key_usages = proto.RepeatedField(
-        proto.MESSAGE, number=3, message="ObjectId",
+        proto.MESSAGE,
+        number=3,
+        message="ObjectId",
     )
 
 
@@ -1381,14 +1773,38 @@ class Subject(proto.Message):
             The postal code of the subject.
     """
 
-    common_name = proto.Field(proto.STRING, number=1,)
-    country_code = proto.Field(proto.STRING, number=2,)
-    organization = proto.Field(proto.STRING, number=3,)
-    organizational_unit = proto.Field(proto.STRING, number=4,)
-    locality = proto.Field(proto.STRING, number=5,)
-    province = proto.Field(proto.STRING, number=6,)
-    street_address = proto.Field(proto.STRING, number=7,)
-    postal_code = proto.Field(proto.STRING, number=8,)
+    common_name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    country_code = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    organization = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    organizational_unit = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    locality = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    province = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    street_address = proto.Field(
+        proto.STRING,
+        number=7,
+    )
+    postal_code = proto.Field(
+        proto.STRING,
+        number=8,
+    )
 
 
 class SubjectAltNames(proto.Message):
@@ -1415,11 +1831,27 @@ class SubjectAltNames(proto.Message):
             encoded UTF8String.
     """
 
-    dns_names = proto.RepeatedField(proto.STRING, number=1,)
-    uris = proto.RepeatedField(proto.STRING, number=2,)
-    email_addresses = proto.RepeatedField(proto.STRING, number=3,)
-    ip_addresses = proto.RepeatedField(proto.STRING, number=4,)
-    custom_sans = proto.RepeatedField(proto.MESSAGE, number=5, message="X509Extension",)
+    dns_names = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
+    uris = proto.RepeatedField(
+        proto.STRING,
+        number=2,
+    )
+    email_addresses = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
+    ip_addresses = proto.RepeatedField(
+        proto.STRING,
+        number=4,
+    )
+    custom_sans = proto.RepeatedField(
+        proto.MESSAGE,
+        number=5,
+        message="X509Extension",
+    )
 
 
 class CertificateIdentityConstraints(proto.Message):
@@ -1456,10 +1888,20 @@ class CertificateIdentityConstraints(proto.Message):
             This field is a member of `oneof`_ ``_allow_subject_alt_names_passthrough``.
     """
 
-    cel_expression = proto.Field(proto.MESSAGE, number=1, message=expr_pb2.Expr,)
-    allow_subject_passthrough = proto.Field(proto.BOOL, number=2, optional=True,)
+    cel_expression = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=expr_pb2.Expr,
+    )
+    allow_subject_passthrough = proto.Field(
+        proto.BOOL,
+        number=2,
+        optional=True,
+    )
     allow_subject_alt_names_passthrough = proto.Field(
-        proto.BOOL, number=3, optional=True,
+        proto.BOOL,
+        number=3,
+        optional=True,
     )
 
 
@@ -1496,10 +1938,14 @@ class CertificateExtensionConstraints(proto.Message):
         AIA_OCSP_SERVERS = 5
 
     known_extensions = proto.RepeatedField(
-        proto.ENUM, number=1, enum=KnownCertificateExtension,
+        proto.ENUM,
+        number=1,
+        enum=KnownCertificateExtension,
     )
     additional_extensions = proto.RepeatedField(
-        proto.MESSAGE, number=2, message="ObjectId",
+        proto.MESSAGE,
+        number=2,
+        message="ObjectId",
     )
 
 
