@@ -13,12 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 import proto  # type: ignore
 
 from google.cloud.security.privateca_v1.types import resources
-from google.protobuf import field_mask_pb2  # type: ignore
-from google.protobuf import timestamp_pb2  # type: ignore
-
 
 __protobuf__ = proto.module(
     package="google.cloud.security.privateca.v1",
@@ -142,12 +141,31 @@ class CreateCertificateRequest(proto.Message):
             to "my-ca".
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    certificate_id = proto.Field(proto.STRING, number=2,)
-    certificate = proto.Field(proto.MESSAGE, number=3, message=resources.Certificate,)
-    request_id = proto.Field(proto.STRING, number=4,)
-    validate_only = proto.Field(proto.BOOL, number=5,)
-    issuing_certificate_authority_id = proto.Field(proto.STRING, number=6,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    certificate_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    certificate = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=resources.Certificate,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    validate_only = proto.Field(
+        proto.BOOL,
+        number=5,
+    )
+    issuing_certificate_authority_id = proto.Field(
+        proto.STRING,
+        number=6,
+    )
 
 
 class GetCertificateRequest(proto.Message):
@@ -163,7 +181,10 @@ class GetCertificateRequest(proto.Message):
             to get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListCertificatesRequest(proto.Message):
@@ -200,11 +221,26 @@ class ListCertificatesRequest(proto.Message):
             documentation <https://cloud.google.com/certificate-authority-service/docs/sorting-filtering-certificates#sorting_support>`__.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListCertificatesResponse(proto.Message):
@@ -229,10 +265,18 @@ class ListCertificatesResponse(proto.Message):
         return self
 
     certificates = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=resources.Certificate,
+        proto.MESSAGE,
+        number=1,
+        message=resources.Certificate,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=3,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
 
 
 class RevokeCertificateRequest(proto.Message):
@@ -270,9 +314,19 @@ class RevokeCertificateRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    reason = proto.Field(proto.ENUM, number=2, enum=resources.RevocationReason,)
-    request_id = proto.Field(proto.STRING, number=3,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    reason = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=resources.RevocationReason,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class UpdateCertificateRequest(proto.Message):
@@ -308,11 +362,20 @@ class UpdateCertificateRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    certificate = proto.Field(proto.MESSAGE, number=1, message=resources.Certificate,)
+    certificate = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=resources.Certificate,
+    )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    request_id = proto.Field(proto.STRING, number=3,)
 
 
 class ActivateCertificateAuthorityRequest(proto.Message):
@@ -353,12 +416,23 @@ class ActivateCertificateAuthorityRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    pem_ca_certificate = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    pem_ca_certificate = proto.Field(
+        proto.STRING,
+        number=2,
+    )
     subordinate_config = proto.Field(
-        proto.MESSAGE, number=3, message=resources.SubordinateConfig,
+        proto.MESSAGE,
+        number=3,
+        message=resources.SubordinateConfig,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=4,
     )
-    request_id = proto.Field(proto.STRING, number=4,)
 
 
 class CreateCertificateAuthorityRequest(proto.Message):
@@ -400,12 +474,23 @@ class CreateCertificateAuthorityRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    certificate_authority_id = proto.Field(proto.STRING, number=2,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    certificate_authority_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
     certificate_authority = proto.Field(
-        proto.MESSAGE, number=3, message=resources.CertificateAuthority,
+        proto.MESSAGE,
+        number=3,
+        message=resources.CertificateAuthority,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=4,
     )
-    request_id = proto.Field(proto.STRING, number=4,)
 
 
 class DisableCertificateAuthorityRequest(proto.Message):
@@ -439,8 +524,14 @@ class DisableCertificateAuthorityRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class EnableCertificateAuthorityRequest(proto.Message):
@@ -474,8 +565,14 @@ class EnableCertificateAuthorityRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class FetchCertificateAuthorityCsrRequest(proto.Message):
@@ -490,7 +587,10 @@ class FetchCertificateAuthorityCsrRequest(proto.Message):
             ``projects/*/locations/*/caPools/*/certificateAuthorities/*``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class FetchCertificateAuthorityCsrResponse(proto.Message):
@@ -503,7 +603,10 @@ class FetchCertificateAuthorityCsrResponse(proto.Message):
             certificate signing request (CSR).
     """
 
-    pem_csr = proto.Field(proto.STRING, number=1,)
+    pem_csr = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class GetCertificateAuthorityRequest(proto.Message):
@@ -519,7 +622,10 @@ class GetCertificateAuthorityRequest(proto.Message):
             to get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListCertificateAuthoritiesRequest(proto.Message):
@@ -553,11 +659,26 @@ class ListCertificateAuthoritiesRequest(proto.Message):
             sorted.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListCertificateAuthoritiesResponse(proto.Message):
@@ -582,10 +703,18 @@ class ListCertificateAuthoritiesResponse(proto.Message):
         return self
 
     certificate_authorities = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=resources.CertificateAuthority,
+        proto.MESSAGE,
+        number=1,
+        message=resources.CertificateAuthority,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=3,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
 
 
 class UndeleteCertificateAuthorityRequest(proto.Message):
@@ -619,8 +748,14 @@ class UndeleteCertificateAuthorityRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class DeleteCertificateAuthorityRequest(proto.Message):
@@ -657,11 +792,31 @@ class DeleteCertificateAuthorityRequest(proto.Message):
             deleted even if the CA has active certs. Active
             certs include both unrevoked and unexpired
             certs.
+        skip_grace_period (bool):
+            Optional. If this flag is set, the
+            Certificate Authority will be deleted as soon as
+            possible without a 30-day grace period where
+            undeletion would have been allowed. If you
+            proceed, there will be no way to recover this
+            CA.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=2,)
-    ignore_active_certificates = proto.Field(proto.BOOL, number=4,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    ignore_active_certificates = proto.Field(
+        proto.BOOL,
+        number=4,
+    )
+    skip_grace_period = proto.Field(
+        proto.BOOL,
+        number=5,
+    )
 
 
 class UpdateCertificateAuthorityRequest(proto.Message):
@@ -698,12 +853,19 @@ class UpdateCertificateAuthorityRequest(proto.Message):
     """
 
     certificate_authority = proto.Field(
-        proto.MESSAGE, number=1, message=resources.CertificateAuthority,
+        proto.MESSAGE,
+        number=1,
+        message=resources.CertificateAuthority,
     )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    request_id = proto.Field(proto.STRING, number=3,)
 
 
 class CreateCaPoolRequest(proto.Message):
@@ -743,10 +905,23 @@ class CreateCaPoolRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    ca_pool_id = proto.Field(proto.STRING, number=2,)
-    ca_pool = proto.Field(proto.MESSAGE, number=3, message=resources.CaPool,)
-    request_id = proto.Field(proto.STRING, number=4,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    ca_pool_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    ca_pool = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=resources.CaPool,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class UpdateCaPoolRequest(proto.Message):
@@ -782,11 +957,20 @@ class UpdateCaPoolRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    ca_pool = proto.Field(proto.MESSAGE, number=1, message=resources.CaPool,)
+    ca_pool = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=resources.CaPool,
+    )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    request_id = proto.Field(proto.STRING, number=3,)
 
 
 class DeleteCaPoolRequest(proto.Message):
@@ -819,8 +1003,14 @@ class DeleteCaPoolRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class FetchCaCertsRequest(proto.Message):
@@ -853,8 +1043,14 @@ class FetchCaCertsRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    ca_pool = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=2,)
+    ca_pool = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class FetchCaCertsResponse(proto.Message):
@@ -879,9 +1075,16 @@ class FetchCaCertsResponse(proto.Message):
                 leaf to root order.
         """
 
-        certificates = proto.RepeatedField(proto.STRING, number=1,)
+        certificates = proto.RepeatedField(
+            proto.STRING,
+            number=1,
+        )
 
-    ca_certs = proto.RepeatedField(proto.MESSAGE, number=1, message=CertChain,)
+    ca_certs = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=CertChain,
+    )
 
 
 class GetCaPoolRequest(proto.Message):
@@ -896,7 +1099,10 @@ class GetCaPoolRequest(proto.Message):
             get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListCaPoolsRequest(proto.Message):
@@ -928,11 +1134,26 @@ class ListCaPoolsRequest(proto.Message):
             sorted.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListCaPoolsResponse(proto.Message):
@@ -956,9 +1177,19 @@ class ListCaPoolsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    ca_pools = proto.RepeatedField(proto.MESSAGE, number=1, message=resources.CaPool,)
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
+    ca_pools = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=resources.CaPool,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
 
 
 class GetCertificateRevocationListRequest(proto.Message):
@@ -974,7 +1205,10 @@ class GetCertificateRevocationListRequest(proto.Message):
             to get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListCertificateRevocationListsRequest(proto.Message):
@@ -1008,11 +1242,26 @@ class ListCertificateRevocationListsRequest(proto.Message):
             sorted.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListCertificateRevocationListsResponse(proto.Message):
@@ -1037,10 +1286,18 @@ class ListCertificateRevocationListsResponse(proto.Message):
         return self
 
     certificate_revocation_lists = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=resources.CertificateRevocationList,
+        proto.MESSAGE,
+        number=1,
+        message=resources.CertificateRevocationList,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=3,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
 
 
 class UpdateCertificateRevocationListRequest(proto.Message):
@@ -1077,12 +1334,19 @@ class UpdateCertificateRevocationListRequest(proto.Message):
     """
 
     certificate_revocation_list = proto.Field(
-        proto.MESSAGE, number=1, message=resources.CertificateRevocationList,
+        proto.MESSAGE,
+        number=1,
+        message=resources.CertificateRevocationList,
     )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    request_id = proto.Field(proto.STRING, number=3,)
 
 
 class CreateCertificateTemplateRequest(proto.Message):
@@ -1123,12 +1387,23 @@ class CreateCertificateTemplateRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    certificate_template_id = proto.Field(proto.STRING, number=2,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    certificate_template_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
     certificate_template = proto.Field(
-        proto.MESSAGE, number=3, message=resources.CertificateTemplate,
+        proto.MESSAGE,
+        number=3,
+        message=resources.CertificateTemplate,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=4,
     )
-    request_id = proto.Field(proto.STRING, number=4,)
 
 
 class DeleteCertificateTemplateRequest(proto.Message):
@@ -1162,8 +1437,14 @@ class DeleteCertificateTemplateRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class GetCertificateTemplateRequest(proto.Message):
@@ -1179,7 +1460,10 @@ class GetCertificateTemplateRequest(proto.Message):
             to get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListCertificateTemplatesRequest(proto.Message):
@@ -1212,11 +1496,26 @@ class ListCertificateTemplatesRequest(proto.Message):
             sorted.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListCertificateTemplatesResponse(proto.Message):
@@ -1241,10 +1540,18 @@ class ListCertificateTemplatesResponse(proto.Message):
         return self
 
     certificate_templates = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=resources.CertificateTemplate,
+        proto.MESSAGE,
+        number=1,
+        message=resources.CertificateTemplate,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=3,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
 
 
 class UpdateCertificateTemplateRequest(proto.Message):
@@ -1281,12 +1588,19 @@ class UpdateCertificateTemplateRequest(proto.Message):
     """
 
     certificate_template = proto.Field(
-        proto.MESSAGE, number=1, message=resources.CertificateTemplate,
+        proto.MESSAGE,
+        number=1,
+        message=resources.CertificateTemplate,
     )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    request_id = proto.Field(proto.STRING, number=3,)
 
 
 class OperationMetadata(proto.Message):
@@ -1319,13 +1633,36 @@ class OperationMetadata(proto.Message):
             operation.
     """
 
-    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    target = proto.Field(proto.STRING, number=3,)
-    verb = proto.Field(proto.STRING, number=4,)
-    status_message = proto.Field(proto.STRING, number=5,)
-    requested_cancellation = proto.Field(proto.BOOL, number=6,)
-    api_version = proto.Field(proto.STRING, number=7,)
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    target = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    verb = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    status_message = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    requested_cancellation = proto.Field(
+        proto.BOOL,
+        number=6,
+    )
+    api_version = proto.Field(
+        proto.STRING,
+        number=7,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
