@@ -13,12 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
-
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.protobuf import wrappers_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.security.privateca.v1beta1",
@@ -169,7 +167,7 @@ class CertificateAuthority(proto.Message):
             Output only. The time at which this
             [CertificateAuthority][google.cloud.security.privateca.v1beta1.CertificateAuthority]
             will be deleted, if scheduled for deletion.
-        labels (Sequence[google.cloud.security.privateca_v1beta1.types.CertificateAuthority.LabelsEntry]):
+        labels (Mapping[str, str]):
             Optional. Labels with user-defined metadata.
     """
 
@@ -241,8 +239,14 @@ class CertificateAuthority(proto.Message):
                 certificate is revoked.
         """
 
-        include_ca_cert_url = proto.Field(proto.BOOL, number=1,)
-        include_crl_access_url = proto.Field(proto.BOOL, number=2,)
+        include_ca_cert_url = proto.Field(
+            proto.BOOL,
+            number=1,
+        )
+        include_crl_access_url = proto.Field(
+            proto.BOOL,
+            number=2,
+        )
 
     class CertificateAuthorityPolicy(proto.Message):
         r"""The issuing policy for a
@@ -346,7 +350,9 @@ class CertificateAuthority(proto.Message):
             """
 
             allowed_config_values = proto.RepeatedField(
-                proto.MESSAGE, number=1, message="ReusableConfigWrapper",
+                proto.MESSAGE,
+                number=1,
+                message="ReusableConfigWrapper",
             )
 
         class AllowedSubjectAltNames(proto.Message):
@@ -392,12 +398,30 @@ class CertificateAuthority(proto.Message):
                     X509Extension values.
             """
 
-            allowed_dns_names = proto.RepeatedField(proto.STRING, number=1,)
-            allowed_uris = proto.RepeatedField(proto.STRING, number=2,)
-            allowed_email_addresses = proto.RepeatedField(proto.STRING, number=3,)
-            allowed_ips = proto.RepeatedField(proto.STRING, number=4,)
-            allow_globbing_dns_wildcards = proto.Field(proto.BOOL, number=5,)
-            allow_custom_sans = proto.Field(proto.BOOL, number=6,)
+            allowed_dns_names = proto.RepeatedField(
+                proto.STRING,
+                number=1,
+            )
+            allowed_uris = proto.RepeatedField(
+                proto.STRING,
+                number=2,
+            )
+            allowed_email_addresses = proto.RepeatedField(
+                proto.STRING,
+                number=3,
+            )
+            allowed_ips = proto.RepeatedField(
+                proto.STRING,
+                number=4,
+            )
+            allow_globbing_dns_wildcards = proto.Field(
+                proto.BOOL,
+                number=5,
+            )
+            allow_custom_sans = proto.Field(
+                proto.BOOL,
+                number=6,
+            )
 
         class IssuanceModes(proto.Message):
             r"""[IssuanceModes][google.cloud.security.privateca.v1beta1.CertificateAuthority.CertificateAuthorityPolicy.IssuanceModes]
@@ -418,8 +442,14 @@ class CertificateAuthority(proto.Message):
                     [CertificateConfig][google.cloud.security.privateca.v1beta1.CertificateConfig].
             """
 
-            allow_csr_based_issuance = proto.Field(proto.BOOL, number=1,)
-            allow_config_based_issuance = proto.Field(proto.BOOL, number=2,)
+            allow_csr_based_issuance = proto.Field(
+                proto.BOOL,
+                number=1,
+            )
+            allow_config_based_issuance = proto.Field(
+                proto.BOOL,
+                number=2,
+            )
 
         allowed_config_list = proto.Field(
             proto.MESSAGE,
@@ -434,16 +464,23 @@ class CertificateAuthority(proto.Message):
             message="ReusableConfigWrapper",
         )
         allowed_locations_and_organizations = proto.RepeatedField(
-            proto.MESSAGE, number=3, message="Subject",
+            proto.MESSAGE,
+            number=3,
+            message="Subject",
+        )
+        allowed_common_names = proto.RepeatedField(
+            proto.STRING,
+            number=4,
         )
-        allowed_common_names = proto.RepeatedField(proto.STRING, number=4,)
         allowed_sans = proto.Field(
             proto.MESSAGE,
             number=5,
             message="CertificateAuthority.CertificateAuthorityPolicy.AllowedSubjectAltNames",
         )
         maximum_lifetime = proto.Field(
-            proto.MESSAGE, number=6, message=duration_pb2.Duration,
+            proto.MESSAGE,
+            number=6,
+            message=duration_pb2.Duration,
         )
         allowed_issuance_modes = proto.Field(
             proto.MESSAGE,
@@ -469,8 +506,14 @@ class CertificateAuthority(proto.Message):
                 been activated.
         """
 
-        ca_certificate_access_url = proto.Field(proto.STRING, number=1,)
-        crl_access_url = proto.Field(proto.STRING, number=2,)
+        ca_certificate_access_url = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        crl_access_url = proto.Field(
+            proto.STRING,
+            number=2,
+        )
 
     class KeyVersionSpec(proto.Message):
         r"""A Cloud KMS key configuration that a
@@ -503,7 +546,11 @@ class CertificateAuthority(proto.Message):
                 This field is a member of `oneof`_ ``KeyVersion``.
         """
 
-        cloud_kms_key_version = proto.Field(proto.STRING, number=1, oneof="KeyVersion",)
+        cloud_kms_key_version = proto.Field(
+            proto.STRING,
+            number=1,
+            oneof="KeyVersion",
+        )
         algorithm = proto.Field(
             proto.ENUM,
             number=2,
@@ -511,36 +558,93 @@ class CertificateAuthority(proto.Message):
             enum="CertificateAuthority.SignHashAlgorithm",
         )
 
-    name = proto.Field(proto.STRING, number=1,)
-    type_ = proto.Field(proto.ENUM, number=2, enum=Type,)
-    tier = proto.Field(proto.ENUM, number=3, enum=Tier,)
-    config = proto.Field(proto.MESSAGE, number=4, message="CertificateConfig",)
-    lifetime = proto.Field(proto.MESSAGE, number=5, message=duration_pb2.Duration,)
-    key_spec = proto.Field(proto.MESSAGE, number=6, message=KeyVersionSpec,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    type_ = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=Type,
+    )
+    tier = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum=Tier,
+    )
+    config = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message="CertificateConfig",
+    )
+    lifetime = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=duration_pb2.Duration,
+    )
+    key_spec = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message=KeyVersionSpec,
+    )
     certificate_policy = proto.Field(
-        proto.MESSAGE, number=7, message=CertificateAuthorityPolicy,
+        proto.MESSAGE,
+        number=7,
+        message=CertificateAuthorityPolicy,
+    )
+    issuing_options = proto.Field(
+        proto.MESSAGE,
+        number=8,
+        message=IssuingOptions,
     )
-    issuing_options = proto.Field(proto.MESSAGE, number=8, message=IssuingOptions,)
     subordinate_config = proto.Field(
-        proto.MESSAGE, number=19, message="SubordinateConfig",
+        proto.MESSAGE,
+        number=19,
+        message="SubordinateConfig",
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=10,
+        enum=State,
+    )
+    pem_ca_certificates = proto.RepeatedField(
+        proto.STRING,
+        number=9,
     )
-    state = proto.Field(proto.ENUM, number=10, enum=State,)
-    pem_ca_certificates = proto.RepeatedField(proto.STRING, number=9,)
     ca_certificate_descriptions = proto.RepeatedField(
-        proto.MESSAGE, number=12, message="CertificateDescription",
+        proto.MESSAGE,
+        number=12,
+        message="CertificateDescription",
+    )
+    gcs_bucket = proto.Field(
+        proto.STRING,
+        number=13,
+    )
+    access_urls = proto.Field(
+        proto.MESSAGE,
+        number=14,
+        message=AccessUrls,
     )
-    gcs_bucket = proto.Field(proto.STRING, number=13,)
-    access_urls = proto.Field(proto.MESSAGE, number=14, message=AccessUrls,)
     create_time = proto.Field(
-        proto.MESSAGE, number=15, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=15,
+        message=timestamp_pb2.Timestamp,
     )
     update_time = proto.Field(
-        proto.MESSAGE, number=16, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=16,
+        message=timestamp_pb2.Timestamp,
     )
     delete_time = proto.Field(
-        proto.MESSAGE, number=17, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=17,
+        message=timestamp_pb2.Timestamp,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=18,
     )
-    labels = proto.MapField(proto.STRING, proto.STRING, number=18,)
 
 
 class CertificateRevocationList(proto.Message):
@@ -579,7 +683,7 @@ class CertificateRevocationList(proto.Message):
             Output only. The time at which this
             [CertificateRevocationList][google.cloud.security.privateca.v1beta1.CertificateRevocationList]
             was updated.
-        labels (Sequence[google.cloud.security.privateca_v1beta1.types.CertificateRevocationList.LabelsEntry]):
+        labels (Mapping[str, str]):
             Optional. Labels with user-defined metadata.
     """
 
@@ -611,21 +715,61 @@ class CertificateRevocationList(proto.Message):
                 was revoked.
         """
 
-        certificate = proto.Field(proto.STRING, number=1,)
-        hex_serial_number = proto.Field(proto.STRING, number=2,)
-        revocation_reason = proto.Field(proto.ENUM, number=3, enum="RevocationReason",)
+        certificate = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        hex_serial_number = proto.Field(
+            proto.STRING,
+            number=2,
+        )
+        revocation_reason = proto.Field(
+            proto.ENUM,
+            number=3,
+            enum="RevocationReason",
+        )
 
-    name = proto.Field(proto.STRING, number=1,)
-    sequence_number = proto.Field(proto.INT64, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    sequence_number = proto.Field(
+        proto.INT64,
+        number=2,
+    )
     revoked_certificates = proto.RepeatedField(
-        proto.MESSAGE, number=3, message=RevokedCertificate,
+        proto.MESSAGE,
+        number=3,
+        message=RevokedCertificate,
+    )
+    pem_crl = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    access_url = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=6,
+        enum=State,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=8,
+        message=timestamp_pb2.Timestamp,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=9,
     )
-    pem_crl = proto.Field(proto.STRING, number=4,)
-    access_url = proto.Field(proto.STRING, number=5,)
-    state = proto.Field(proto.ENUM, number=6, enum=State,)
-    create_time = proto.Field(proto.MESSAGE, number=7, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=8, message=timestamp_pb2.Timestamp,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=9,)
 
 
 class Certificate(proto.Message):
@@ -686,7 +830,7 @@ class Certificate(proto.Message):
             Output only. The time at which this
             [Certificate][google.cloud.security.privateca.v1beta1.Certificate]
             was updated.
-        labels (Sequence[google.cloud.security.privateca_v1beta1.types.Certificate.LabelsEntry]):
+        labels (Mapping[str, str]):
             Optional. Labels with user-defined metadata.
     """
 
@@ -705,33 +849,70 @@ class Certificate(proto.Message):
                 was revoked.
         """
 
-        revocation_state = proto.Field(proto.ENUM, number=1, enum="RevocationReason",)
+        revocation_state = proto.Field(
+            proto.ENUM,
+            number=1,
+            enum="RevocationReason",
+        )
         revocation_time = proto.Field(
-            proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,
+            proto.MESSAGE,
+            number=2,
+            message=timestamp_pb2.Timestamp,
         )
 
-    name = proto.Field(proto.STRING, number=1,)
-    pem_csr = proto.Field(proto.STRING, number=2, oneof="certificate_config",)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    pem_csr = proto.Field(
+        proto.STRING,
+        number=2,
+        oneof="certificate_config",
+    )
     config = proto.Field(
         proto.MESSAGE,
         number=3,
         oneof="certificate_config",
         message="CertificateConfig",
     )
-    lifetime = proto.Field(proto.MESSAGE, number=4, message=duration_pb2.Duration,)
+    lifetime = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=duration_pb2.Duration,
+    )
     revocation_details = proto.Field(
-        proto.MESSAGE, number=5, message=RevocationDetails,
+        proto.MESSAGE,
+        number=5,
+        message=RevocationDetails,
+    )
+    pem_certificate = proto.Field(
+        proto.STRING,
+        number=6,
     )
-    pem_certificate = proto.Field(proto.STRING, number=6,)
     certificate_description = proto.Field(
-        proto.MESSAGE, number=7, message="CertificateDescription",
+        proto.MESSAGE,
+        number=7,
+        message="CertificateDescription",
+    )
+    pem_certificate_chain = proto.RepeatedField(
+        proto.STRING,
+        number=8,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=9,
+        message=timestamp_pb2.Timestamp,
     )
-    pem_certificate_chain = proto.RepeatedField(proto.STRING, number=8,)
-    create_time = proto.Field(proto.MESSAGE, number=9, message=timestamp_pb2.Timestamp,)
     update_time = proto.Field(
-        proto.MESSAGE, number=10, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=10,
+        message=timestamp_pb2.Timestamp,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=11,
     )
-    labels = proto.MapField(proto.STRING, proto.STRING, number=11,)
 
 
 class ReusableConfig(proto.Message):
@@ -762,16 +943,38 @@ class ReusableConfig(proto.Message):
             Output only. The time at which this
             [ReusableConfig][google.cloud.security.privateca.v1beta1.ReusableConfig]
             was updated.
-        labels (Sequence[google.cloud.security.privateca_v1beta1.types.ReusableConfig.LabelsEntry]):
+        labels (Mapping[str, str]):
             Optional. Labels with user-defined metadata.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    values = proto.Field(proto.MESSAGE, number=2, message="ReusableConfigValues",)
-    description = proto.Field(proto.STRING, number=3,)
-    create_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=6,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    values = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="ReusableConfigValues",
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=timestamp_pb2.Timestamp,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=6,
+    )
 
 
 class ReusableConfigValues(proto.Message):
@@ -821,17 +1024,40 @@ class ReusableConfigValues(proto.Message):
                 length will be omitted from the CA certificate.
         """
 
-        is_ca = proto.Field(proto.MESSAGE, number=1, message=wrappers_pb2.BoolValue,)
+        is_ca = proto.Field(
+            proto.MESSAGE,
+            number=1,
+            message=wrappers_pb2.BoolValue,
+        )
         max_issuer_path_length = proto.Field(
-            proto.MESSAGE, number=2, message=wrappers_pb2.Int32Value,
+            proto.MESSAGE,
+            number=2,
+            message=wrappers_pb2.Int32Value,
         )
 
-    key_usage = proto.Field(proto.MESSAGE, number=1, message="KeyUsage",)
-    ca_options = proto.Field(proto.MESSAGE, number=2, message=CaOptions,)
-    policy_ids = proto.RepeatedField(proto.MESSAGE, number=3, message="ObjectId",)
-    aia_ocsp_servers = proto.RepeatedField(proto.STRING, number=4,)
+    key_usage = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="KeyUsage",
+    )
+    ca_options = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=CaOptions,
+    )
+    policy_ids = proto.RepeatedField(
+        proto.MESSAGE,
+        number=3,
+        message="ObjectId",
+    )
+    aia_ocsp_servers = proto.RepeatedField(
+        proto.STRING,
+        number=4,
+    )
     additional_extensions = proto.RepeatedField(
-        proto.MESSAGE, number=5, message="X509Extension",
+        proto.MESSAGE,
+        number=5,
+        message="X509Extension",
     )
 
 
@@ -862,9 +1088,16 @@ class ReusableConfigWrapper(proto.Message):
             This field is a member of `oneof`_ ``config_values``.
     """
 
-    reusable_config = proto.Field(proto.STRING, number=1, oneof="config_values",)
+    reusable_config = proto.Field(
+        proto.STRING,
+        number=1,
+        oneof="config_values",
+    )
     reusable_config_values = proto.Field(
-        proto.MESSAGE, number=2, oneof="config_values", message="ReusableConfigValues",
+        proto.MESSAGE,
+        number=2,
+        oneof="config_values",
+        message="ReusableConfigValues",
     )
 
 
@@ -911,10 +1144,15 @@ class SubordinateConfig(proto.Message):
                 order according to RFC 5246.
         """
 
-        pem_certificates = proto.RepeatedField(proto.STRING, number=1,)
+        pem_certificates = proto.RepeatedField(
+            proto.STRING,
+            number=1,
+        )
 
     certificate_authority = proto.Field(
-        proto.STRING, number=1, oneof="subordinate_config",
+        proto.STRING,
+        number=1,
+        oneof="subordinate_config",
     )
     pem_issuer_chain = proto.Field(
         proto.MESSAGE,
@@ -946,8 +1184,15 @@ class PublicKey(proto.Message):
         PEM_RSA_KEY = 1
         PEM_EC_KEY = 2
 
-    type_ = proto.Field(proto.ENUM, number=1, enum=KeyType,)
-    key = proto.Field(proto.BYTES, number=2,)
+    type_ = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=KeyType,
+    )
+    key = proto.Field(
+        proto.BYTES,
+        number=2,
+    )
 
 
 class CertificateConfig(proto.Message):
@@ -990,17 +1235,36 @@ class CertificateConfig(proto.Message):
                 fields.
         """
 
-        subject = proto.Field(proto.MESSAGE, number=1, message="Subject",)
-        common_name = proto.Field(proto.STRING, number=2,)
+        subject = proto.Field(
+            proto.MESSAGE,
+            number=1,
+            message="Subject",
+        )
+        common_name = proto.Field(
+            proto.STRING,
+            number=2,
+        )
         subject_alt_name = proto.Field(
-            proto.MESSAGE, number=3, message="SubjectAltNames",
+            proto.MESSAGE,
+            number=3,
+            message="SubjectAltNames",
         )
 
-    subject_config = proto.Field(proto.MESSAGE, number=1, message=SubjectConfig,)
+    subject_config = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=SubjectConfig,
+    )
     reusable_config = proto.Field(
-        proto.MESSAGE, number=2, message="ReusableConfigWrapper",
+        proto.MESSAGE,
+        number=2,
+        message="ReusableConfigWrapper",
+    )
+    public_key = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="PublicKey",
     )
-    public_key = proto.Field(proto.MESSAGE, number=3, message="PublicKey",)
 
 
 class CertificateDescription(proto.Message):
@@ -1066,18 +1330,38 @@ class CertificateDescription(proto.Message):
                 The time at which the certificate expires.
         """
 
-        subject = proto.Field(proto.MESSAGE, number=1, message="Subject",)
-        common_name = proto.Field(proto.STRING, number=2,)
+        subject = proto.Field(
+            proto.MESSAGE,
+            number=1,
+            message="Subject",
+        )
+        common_name = proto.Field(
+            proto.STRING,
+            number=2,
+        )
         subject_alt_name = proto.Field(
-            proto.MESSAGE, number=3, message="SubjectAltNames",
+            proto.MESSAGE,
+            number=3,
+            message="SubjectAltNames",
+        )
+        hex_serial_number = proto.Field(
+            proto.STRING,
+            number=4,
+        )
+        lifetime = proto.Field(
+            proto.MESSAGE,
+            number=5,
+            message=duration_pb2.Duration,
         )
-        hex_serial_number = proto.Field(proto.STRING, number=4,)
-        lifetime = proto.Field(proto.MESSAGE, number=5, message=duration_pb2.Duration,)
         not_before_time = proto.Field(
-            proto.MESSAGE, number=6, message=timestamp_pb2.Timestamp,
+            proto.MESSAGE,
+            number=6,
+            message=timestamp_pb2.Timestamp,
         )
         not_after_time = proto.Field(
-            proto.MESSAGE, number=7, message=timestamp_pb2.Timestamp,
+            proto.MESSAGE,
+            number=7,
+            message=timestamp_pb2.Timestamp,
         )
 
     class KeyId(proto.Message):
@@ -1091,7 +1375,10 @@ class CertificateDescription(proto.Message):
                 160 bit SHA-1 hash of the public key.
         """
 
-        key_id = proto.Field(proto.STRING, number=1,)
+        key_id = proto.Field(
+            proto.STRING,
+            number=1,
+        )
 
     class CertificateFingerprint(proto.Message):
         r"""A group of fingerprints for the x509 certificate.
@@ -1102,21 +1389,48 @@ class CertificateDescription(proto.Message):
                 the DER x509 certificate.
         """
 
-        sha256_hash = proto.Field(proto.STRING, number=1,)
+        sha256_hash = proto.Field(
+            proto.STRING,
+            number=1,
+        )
 
     subject_description = proto.Field(
-        proto.MESSAGE, number=1, message=SubjectDescription,
+        proto.MESSAGE,
+        number=1,
+        message=SubjectDescription,
     )
     config_values = proto.Field(
-        proto.MESSAGE, number=2, message="ReusableConfigValues",
+        proto.MESSAGE,
+        number=2,
+        message="ReusableConfigValues",
+    )
+    public_key = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="PublicKey",
+    )
+    subject_key_id = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=KeyId,
+    )
+    authority_key_id = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=KeyId,
+    )
+    crl_distribution_points = proto.RepeatedField(
+        proto.STRING,
+        number=6,
+    )
+    aia_issuing_certificate_urls = proto.RepeatedField(
+        proto.STRING,
+        number=7,
     )
-    public_key = proto.Field(proto.MESSAGE, number=3, message="PublicKey",)
-    subject_key_id = proto.Field(proto.MESSAGE, number=4, message=KeyId,)
-    authority_key_id = proto.Field(proto.MESSAGE, number=5, message=KeyId,)
-    crl_distribution_points = proto.RepeatedField(proto.STRING, number=6,)
-    aia_issuing_certificate_urls = proto.RepeatedField(proto.STRING, number=7,)
     cert_fingerprint = proto.Field(
-        proto.MESSAGE, number=8, message=CertificateFingerprint,
+        proto.MESSAGE,
+        number=8,
+        message=CertificateFingerprint,
     )
 
 
@@ -1131,7 +1445,10 @@ class ObjectId(proto.Message):
             significant parts of the path come first.
     """
 
-    object_id_path = proto.RepeatedField(proto.INT32, number=1,)
+    object_id_path = proto.RepeatedField(
+        proto.INT32,
+        number=1,
+    )
 
 
 class X509Extension(proto.Message):
@@ -1152,9 +1469,19 @@ class X509Extension(proto.Message):
             Required. The value of this X.509 extension.
     """
 
-    object_id = proto.Field(proto.MESSAGE, number=1, message="ObjectId",)
-    critical = proto.Field(proto.BOOL, number=2,)
-    value = proto.Field(proto.BYTES, number=3,)
+    object_id = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="ObjectId",
+    )
+    critical = proto.Field(
+        proto.BOOL,
+        number=2,
+    )
+    value = proto.Field(
+        proto.BYTES,
+        number=3,
+    )
 
 
 class KeyUsage(proto.Message):
@@ -1205,15 +1532,42 @@ class KeyUsage(proto.Message):
                 The key may be used to decipher only.
         """
 
-        digital_signature = proto.Field(proto.BOOL, number=1,)
-        content_commitment = proto.Field(proto.BOOL, number=2,)
-        key_encipherment = proto.Field(proto.BOOL, number=3,)
-        data_encipherment = proto.Field(proto.BOOL, number=4,)
-        key_agreement = proto.Field(proto.BOOL, number=5,)
-        cert_sign = proto.Field(proto.BOOL, number=6,)
-        crl_sign = proto.Field(proto.BOOL, number=7,)
-        encipher_only = proto.Field(proto.BOOL, number=8,)
-        decipher_only = proto.Field(proto.BOOL, number=9,)
+        digital_signature = proto.Field(
+            proto.BOOL,
+            number=1,
+        )
+        content_commitment = proto.Field(
+            proto.BOOL,
+            number=2,
+        )
+        key_encipherment = proto.Field(
+            proto.BOOL,
+            number=3,
+        )
+        data_encipherment = proto.Field(
+            proto.BOOL,
+            number=4,
+        )
+        key_agreement = proto.Field(
+            proto.BOOL,
+            number=5,
+        )
+        cert_sign = proto.Field(
+            proto.BOOL,
+            number=6,
+        )
+        crl_sign = proto.Field(
+            proto.BOOL,
+            number=7,
+        )
+        encipher_only = proto.Field(
+            proto.BOOL,
+            number=8,
+        )
+        decipher_only = proto.Field(
+            proto.BOOL,
+            number=9,
+        )
 
     class ExtendedKeyUsageOptions(proto.Message):
         r"""[KeyUsage.ExtendedKeyUsageOptions][google.cloud.security.privateca.v1beta1.KeyUsage.ExtendedKeyUsageOptions]
@@ -1248,19 +1602,45 @@ class KeyUsage(proto.Message):
                 responses".
         """
 
-        server_auth = proto.Field(proto.BOOL, number=1,)
-        client_auth = proto.Field(proto.BOOL, number=2,)
-        code_signing = proto.Field(proto.BOOL, number=3,)
-        email_protection = proto.Field(proto.BOOL, number=4,)
-        time_stamping = proto.Field(proto.BOOL, number=5,)
-        ocsp_signing = proto.Field(proto.BOOL, number=6,)
+        server_auth = proto.Field(
+            proto.BOOL,
+            number=1,
+        )
+        client_auth = proto.Field(
+            proto.BOOL,
+            number=2,
+        )
+        code_signing = proto.Field(
+            proto.BOOL,
+            number=3,
+        )
+        email_protection = proto.Field(
+            proto.BOOL,
+            number=4,
+        )
+        time_stamping = proto.Field(
+            proto.BOOL,
+            number=5,
+        )
+        ocsp_signing = proto.Field(
+            proto.BOOL,
+            number=6,
+        )
 
-    base_key_usage = proto.Field(proto.MESSAGE, number=1, message=KeyUsageOptions,)
+    base_key_usage = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=KeyUsageOptions,
+    )
     extended_key_usage = proto.Field(
-        proto.MESSAGE, number=2, message=ExtendedKeyUsageOptions,
+        proto.MESSAGE,
+        number=2,
+        message=ExtendedKeyUsageOptions,
     )
     unknown_extended_key_usages = proto.RepeatedField(
-        proto.MESSAGE, number=3, message="ObjectId",
+        proto.MESSAGE,
+        number=3,
+        message="ObjectId",
     )
 
 
@@ -1287,13 +1667,34 @@ class Subject(proto.Message):
             The postal code of the subject.
     """
 
-    country_code = proto.Field(proto.STRING, number=1,)
-    organization = proto.Field(proto.STRING, number=2,)
-    organizational_unit = proto.Field(proto.STRING, number=3,)
-    locality = proto.Field(proto.STRING, number=4,)
-    province = proto.Field(proto.STRING, number=5,)
-    street_address = proto.Field(proto.STRING, number=6,)
-    postal_code = proto.Field(proto.STRING, number=7,)
+    country_code = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    organization = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    organizational_unit = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    locality = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    province = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    street_address = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    postal_code = proto.Field(
+        proto.STRING,
+        number=7,
+    )
 
 
 class SubjectAltNames(proto.Message):
@@ -1319,11 +1720,27 @@ class SubjectAltNames(proto.Message):
             values.
     """
 
-    dns_names = proto.RepeatedField(proto.STRING, number=1,)
-    uris = proto.RepeatedField(proto.STRING, number=2,)
-    email_addresses = proto.RepeatedField(proto.STRING, number=3,)
-    ip_addresses = proto.RepeatedField(proto.STRING, number=4,)
-    custom_sans = proto.RepeatedField(proto.MESSAGE, number=5, message="X509Extension",)
+    dns_names = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
+    uris = proto.RepeatedField(
+        proto.STRING,
+        number=2,
+    )
+    email_addresses = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
+    ip_addresses = proto.RepeatedField(
+        proto.STRING,
+        number=4,
+    )
+    custom_sans = proto.RepeatedField(
+        proto.MESSAGE,
+        number=5,
+        message="X509Extension",
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
