@@ -13,12 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 import proto  # type: ignore
 
 from google.cloud.security.privateca_v1beta1.types import resources
-from google.protobuf import field_mask_pb2  # type: ignore
-from google.protobuf import timestamp_pb2  # type: ignore
-
 
 __protobuf__ = proto.module(
     package="google.cloud.security.privateca.v1beta1",
@@ -98,10 +97,23 @@ class CreateCertificateRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    certificate_id = proto.Field(proto.STRING, number=2,)
-    certificate = proto.Field(proto.MESSAGE, number=3, message=resources.Certificate,)
-    request_id = proto.Field(proto.STRING, number=4,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    certificate_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    certificate = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=resources.Certificate,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class GetCertificateRequest(proto.Message):
@@ -117,7 +129,10 @@ class GetCertificateRequest(proto.Message):
             to get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListCertificatesRequest(proto.Message):
@@ -155,11 +170,26 @@ class ListCertificatesRequest(proto.Message):
             documentation <https://cloud.google.com/certificate-authority-service/docs/sorting-filtering-certificates#sorting_support>`__.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListCertificatesResponse(proto.Message):
@@ -184,10 +214,18 @@ class ListCertificatesResponse(proto.Message):
         return self
 
     certificates = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=resources.Certificate,
+        proto.MESSAGE,
+        number=1,
+        message=resources.Certificate,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=3,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
 
 
 class RevokeCertificateRequest(proto.Message):
@@ -225,9 +263,19 @@ class RevokeCertificateRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    reason = proto.Field(proto.ENUM, number=2, enum=resources.RevocationReason,)
-    request_id = proto.Field(proto.STRING, number=3,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    reason = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=resources.RevocationReason,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class UpdateCertificateRequest(proto.Message):
@@ -263,11 +311,20 @@ class UpdateCertificateRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    certificate = proto.Field(proto.MESSAGE, number=1, message=resources.Certificate,)
+    certificate = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=resources.Certificate,
+    )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    request_id = proto.Field(proto.STRING, number=3,)
 
 
 class ActivateCertificateAuthorityRequest(proto.Message):
@@ -308,12 +365,23 @@ class ActivateCertificateAuthorityRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    pem_ca_certificate = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    pem_ca_certificate = proto.Field(
+        proto.STRING,
+        number=2,
+    )
     subordinate_config = proto.Field(
-        proto.MESSAGE, number=3, message=resources.SubordinateConfig,
+        proto.MESSAGE,
+        number=3,
+        message=resources.SubordinateConfig,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=4,
     )
-    request_id = proto.Field(proto.STRING, number=4,)
 
 
 class CreateCertificateAuthorityRequest(proto.Message):
@@ -354,12 +422,23 @@ class CreateCertificateAuthorityRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    certificate_authority_id = proto.Field(proto.STRING, number=2,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    certificate_authority_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
     certificate_authority = proto.Field(
-        proto.MESSAGE, number=3, message=resources.CertificateAuthority,
+        proto.MESSAGE,
+        number=3,
+        message=resources.CertificateAuthority,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=4,
     )
-    request_id = proto.Field(proto.STRING, number=4,)
 
 
 class DisableCertificateAuthorityRequest(proto.Message):
@@ -393,8 +472,14 @@ class DisableCertificateAuthorityRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class EnableCertificateAuthorityRequest(proto.Message):
@@ -428,8 +513,14 @@ class EnableCertificateAuthorityRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class FetchCertificateAuthorityCsrRequest(proto.Message):
@@ -444,7 +535,10 @@ class FetchCertificateAuthorityCsrRequest(proto.Message):
             ``projects/*/locations/*/certificateAuthorities/*``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class FetchCertificateAuthorityCsrResponse(proto.Message):
@@ -457,7 +551,10 @@ class FetchCertificateAuthorityCsrResponse(proto.Message):
             certificate signing request (CSR).
     """
 
-    pem_csr = proto.Field(proto.STRING, number=1,)
+    pem_csr = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class GetCertificateAuthorityRequest(proto.Message):
@@ -473,7 +570,10 @@ class GetCertificateAuthorityRequest(proto.Message):
             to get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListCertificateAuthoritiesRequest(proto.Message):
@@ -506,11 +606,26 @@ class ListCertificateAuthoritiesRequest(proto.Message):
             sorted.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListCertificateAuthoritiesResponse(proto.Message):
@@ -535,10 +650,18 @@ class ListCertificateAuthoritiesResponse(proto.Message):
         return self
 
     certificate_authorities = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=resources.CertificateAuthority,
+        proto.MESSAGE,
+        number=1,
+        message=resources.CertificateAuthority,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=3,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
 
 
 class RestoreCertificateAuthorityRequest(proto.Message):
@@ -572,8 +695,14 @@ class RestoreCertificateAuthorityRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class ScheduleDeleteCertificateAuthorityRequest(proto.Message):
@@ -607,8 +736,14 @@ class ScheduleDeleteCertificateAuthorityRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class UpdateCertificateAuthorityRequest(proto.Message):
@@ -645,12 +780,19 @@ class UpdateCertificateAuthorityRequest(proto.Message):
     """
 
     certificate_authority = proto.Field(
-        proto.MESSAGE, number=1, message=resources.CertificateAuthority,
+        proto.MESSAGE,
+        number=1,
+        message=resources.CertificateAuthority,
     )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    request_id = proto.Field(proto.STRING, number=3,)
 
 
 class GetCertificateRevocationListRequest(proto.Message):
@@ -666,7 +808,10 @@ class GetCertificateRevocationListRequest(proto.Message):
             to get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListCertificateRevocationListsRequest(proto.Message):
@@ -700,11 +845,26 @@ class ListCertificateRevocationListsRequest(proto.Message):
             sorted.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListCertificateRevocationListsResponse(proto.Message):
@@ -729,10 +889,18 @@ class ListCertificateRevocationListsResponse(proto.Message):
         return self
 
     certificate_revocation_lists = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=resources.CertificateRevocationList,
+        proto.MESSAGE,
+        number=1,
+        message=resources.CertificateRevocationList,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=3,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
 
 
 class UpdateCertificateRevocationListRequest(proto.Message):
@@ -769,12 +937,19 @@ class UpdateCertificateRevocationListRequest(proto.Message):
     """
 
     certificate_revocation_list = proto.Field(
-        proto.MESSAGE, number=1, message=resources.CertificateRevocationList,
+        proto.MESSAGE,
+        number=1,
+        message=resources.CertificateRevocationList,
     )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    request_id = proto.Field(proto.STRING, number=3,)
 
 
 class GetReusableConfigRequest(proto.Message):
@@ -787,7 +962,10 @@ class GetReusableConfigRequest(proto.Message):
             [ReusableConfigs][] to get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListReusableConfigsRequest(proto.Message):
@@ -820,11 +998,26 @@ class ListReusableConfigsRequest(proto.Message):
             sorted.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListReusableConfigsResponse(proto.Message):
@@ -849,10 +1042,18 @@ class ListReusableConfigsResponse(proto.Message):
         return self
 
     reusable_configs = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=resources.ReusableConfig,
+        proto.MESSAGE,
+        number=1,
+        message=resources.ReusableConfig,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=3,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
 
 
 class OperationMetadata(proto.Message):
@@ -885,13 +1086,36 @@ class OperationMetadata(proto.Message):
             operation.
     """
 
-    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    target = proto.Field(proto.STRING, number=3,)
-    verb = proto.Field(proto.STRING, number=4,)
-    status_message = proto.Field(proto.STRING, number=5,)
-    requested_cancellation = proto.Field(proto.BOOL, number=6,)
-    api_version = proto.Field(proto.STRING, number=7,)
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    target = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    verb = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    status_message = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    requested_cancellation = proto.Field(
+        proto.BOOL,
+        number=6,
+    )
+    api_version = proto.Field(
+        proto.STRING,
+        number=7,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
